# scaraplate

[![GitHub Actions Build status][gha-badge]][gha-link]
[![scaraplate on pypi][pypi-badge]][pypi-link]
[![docs at readthedocs][docs-badge]][docs-link]
[![Licensed under MIT][license-badge]][license-link]
[![Code style: black][black-badge]][black-link]

[gha-badge]: https://img.shields.io/github/workflow/status/rambler-digital-solutions/scaraplate/CI
[gha-link]: https://github.com/rambler-digital-solutions/scaraplate/actions
[pypi-badge]: https://img.shields.io/pypi/v/scaraplate.svg
[pypi-link]: https://pypi.org/project/scaraplate/
[docs-badge]: https://readthedocs.org/projects/scaraplate/badge/?version=latest
[docs-link]: https://scaraplate.readthedocs.io/
[license-badge]: https://scaraplate.readthedocs.io/en/latest/_static/license.svg
[license-link]: https://github.com/rambler-digital-solutions/scaraplate/blob/master/LICENSE
[black-badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]: https://github.com/psf/black


Scaraplate is a wrapper around [cookiecutter][cookiecutter]
which allows to repeatedly rollup project templates onto concrete projects.

[cookiecutter]: https://github.com/cookiecutter/cookiecutter

Docs: https://scaraplate.readthedocs.io/
